==> zio-aws-storagegateway_2.13-5.17.155.2-sources.jar: zio/aws/storagegateway/model/ListAutomaticTapeCreationPoliciesRequest.scala <==
package zio.aws.storagegateway.model
import zio.aws.storagegateway.model.primitives.GatewayARN
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListAutomaticTapeCreationPoliciesRequest(
    gatewayARN: Option[GatewayARN] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest = {
    import ListAutomaticTapeCreationPoliciesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest
      .builder()
      .optionallyWith(
        gatewayARN.map(value => GatewayARN.unwrap(value): java.lang.String)
      )(_.gatewayARN)
      .build()
  }
  def asReadOnly
      : zio.aws.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest.ReadOnly =
    zio.aws.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest
      .wrap(buildAwsValue())
}
object ListAutomaticTapeCreationPoliciesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest =
      zio.aws.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest(
        gatewayARN.map(value => value)
      )
    def gatewayARN: Option[GatewayARN]
    def getGatewayARN: ZIO[Any, AwsError, GatewayARN] =
      AwsError.unwrapOptionField("gatewayARN", gatewayARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest
  ) extends zio.aws.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest.ReadOnly {
    override val gatewayARN: Option[GatewayARN] = scala
      .Option(impl.gatewayARN())
      .map(value => zio.aws.storagegateway.model.primitives.GatewayARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest
  ): zio.aws.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-storagegateway_2.13-5.20.42.1-sources.jar: zio/aws/storagegateway/model/ListAutomaticTapeCreationPoliciesRequest.scala <==
package zio.aws.storagegateway.model
import zio.aws.storagegateway.model.primitives.GatewayARN
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListAutomaticTapeCreationPoliciesRequest(
    gatewayARN: Optional[GatewayARN] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest = {
    import ListAutomaticTapeCreationPoliciesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest
      .builder()
      .optionallyWith(
        gatewayARN.map(value => GatewayARN.unwrap(value): java.lang.String)
      )(_.gatewayARN)
      .build()
  }
  def asReadOnly
      : zio.aws.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest.ReadOnly =
    zio.aws.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest
      .wrap(buildAwsValue())
}
object ListAutomaticTapeCreationPoliciesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest =
      zio.aws.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest(
        gatewayARN.map(value => value)
      )
    def gatewayARN: Optional[GatewayARN]
    def getGatewayARN: ZIO[Any, AwsError, GatewayARN] =
      AwsError.unwrapOptionField("gatewayARN", gatewayARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest
  ) extends zio.aws.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest.ReadOnly {
    override val gatewayARN: Optional[GatewayARN] = zio.aws.core.internal
      .optionalFromNullable(impl.gatewayARN())
      .map(value => zio.aws.storagegateway.model.primitives.GatewayARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest
  ): zio.aws.storagegateway.model.ListAutomaticTapeCreationPoliciesRequest.ReadOnly =
    new Wrapper(impl)
}
